@@ -12,27 +12,25 @@ test_that("Construction, fields access and other basics work in class BipartiteS
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- BipartiteSBM_sampler$new('bernoulli', nbNodes, blockProp, connectParam)
-  expect_error(SimpleSBM_sampler$new('bernouilli',nbNodes, blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', -10    , blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', c(1,2) , blockProp, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, 2, connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, c(0,1), connectParam))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, blockProp, list(mean = matrix( 2, nbBlocks[1], nbBlocks[2]))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, blockProp, list(mean = matrix(-2, nbBlocks[1], nbBlocks[2]))))
-  expect_error(SimpleSBM_sampler$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(0, nbBlocks[1] - 1, nbBlocks[2]))))
+  mySampler <- BipartiteSBM$new('bernoulli', nbNodes, blockProp, connectParam)
+  expect_error(SimpleSBM$new('bernouilli',nbNodes, blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', -10    , blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', c(1,2) , blockProp, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, 2, connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, c(0,1), connectParam))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, blockProp, list(mean = matrix( 2, nbBlocks[1], nbBlocks[2]))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, blockProp, list(mean = matrix(-2, nbBlocks[1], nbBlocks[2]))))
+  expect_error(SimpleSBM$new('bernoulli', nbNodes, FALSE, blockProp, list(mean = matrix(0, nbBlocks[1] - 1, nbBlocks[2]))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "BipartiteSBM_sampler"))
+  expect_true(inherits(mySampler, "BipartiteSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'bernoulli')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, nbNodes)
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes[1]*nbNodes[2])
 
   ## covariates
@@ -43,10 +41,14 @@ test_that("Construction, fields access and other basics work in class BipartiteS
 
   expect_equal(mySampler$connectParam$mean, means)
   expect_null(mySampler$connectParam$var)
+
+  ## network
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), nbNodes)
   expect_true(all(mySampler$expectation >= 0, na.rm = TRUE))
   expect_true(all(mySampler$expectation <= 1, na.rm = TRUE))
-  expect_false(isSymmetric(mySampler$netMatrix))
+  expect_false(isSymmetric(mySampler$networkData))
 
   ## blocks
   expect_equal(mySampler$blockProp, blockProp)
@@ -73,31 +75,33 @@ test_that("Construction, fields access and other basics work in class BipartiteS
   connectParam <- list(mean = means)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- BipartiteSBM_sampler$new('poisson', nbNodes, blockProp, connectParam)
-  expect_error(BipartiteSBM_sampler$new('poison' , nbNodes, blockProp, connectParam))
-  expect_error(BipartiteSBM_sampler$new('poisson', -10    , blockProp, connectParam))
-  expect_error(BipartiteSBM_sampler$new('poisson', nbNodes, -2, connectParam))
-  expect_error(BipartiteSBM_sampler$new('poisson', nbNodes,  c(0,1), connectParam))
-  expect_error(BipartiteSBM_sampler$new('poisson', nbNodes, blockProp, list(mean = matrix(-2, nbBlocks[1], nbBlocks[2]))))
-  expect_error(BipartiteSBM_sampler$new('poisson', nbNodes, blockProp, list(mean = matrix(2 , nbBlocks[1] - 1, nbBlocks[2]))))
+  mySampler <- BipartiteSBM$new('poisson', nbNodes, blockProp, connectParam)
+  expect_error(BipartiteSBM$new('poison' , nbNodes, blockProp, connectParam))
+  expect_error(BipartiteSBM$new('poisson', -10    , blockProp, connectParam))
+  expect_error(BipartiteSBM$new('poisson', nbNodes, -2, connectParam))
+  expect_error(BipartiteSBM$new('poisson', nbNodes,  c(0,1), connectParam))
+  expect_error(BipartiteSBM$new('poisson', nbNodes, blockProp, list(mean = matrix(-2, nbBlocks[1], nbBlocks[2]))))
+  expect_error(BipartiteSBM$new('poisson', nbNodes, blockProp, list(mean = matrix(2 , nbBlocks[1] - 1, nbBlocks[2]))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "BipartiteSBM_sampler"))
+  expect_true(inherits(mySampler, "BipartiteSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'poisson')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, nbNodes)
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes[1]*nbNodes[2])
   expect_equal(mySampler$connectParam$mean, means)
   expect_null(mySampler$connectParam$var)
+
+  ## network
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), nbNodes)
   expect_true(all(mySampler$expectation >= 0, na.rm = TRUE))
-  expect_false(isSymmetric(mySampler$netMatrix))
+  expect_false(isSymmetric(mySampler$networkData))
 
   ## blocks
   expect_equal(mySampler$blockProp, blockProp)
@@ -122,33 +126,35 @@ test_that("Construction, fields access and other basics work in class BipartiteS
   connectParam <- list(mean = means, var = .1)
 
   ## Basic construction - check for wrong specifications
-  mySampler <- BipartiteSBM_sampler$new('gaussian', nbNodes, blockProp, connectParam)
-  expect_error(BipartiteSBM_sampler$new('normal'  , nbNodes, blockProp, connectParam))
-  expect_error(BipartiteSBM_sampler$new('gaussian', -10    , blockProp, connectParam))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes, -2, connectParam))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes,  c(0,1), connectParam))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes, blockProp, list(var = -1, mean = means)))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes, blockProp, list(mean = matrix(runif(nbBlocks**2), nbBlocks, nbBlocks))))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes, blockProp, list(var = 1 , mean = matrix(2 , nbBlocks - 1, nbBlocks))))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes, blockProp, list(mean = matrix(-2, nbBlocks[1], nbBlocks[2]))))
-  expect_error(BipartiteSBM_sampler$new('gaussian', nbNodes, blockProp, list(mean = matrix(2 , nbBlocks[1] - 1, nbBlocks[2]))))
+  mySampler <- BipartiteSBM$new('gaussian', nbNodes, blockProp, connectParam)
+  expect_error(BipartiteSBM$new('normal'  , nbNodes, blockProp, connectParam))
+  expect_error(BipartiteSBM$new('gaussian', -10    , blockProp, connectParam))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes, -2, connectParam))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes,  c(0,1), connectParam))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes, blockProp, list(var = -1, mean = means)))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes, blockProp, list(mean = matrix(runif(nbBlocks**2), nbBlocks, nbBlocks))))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes, blockProp, list(var = 1 , mean = matrix(2 , nbBlocks - 1, nbBlocks))))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes, blockProp, list(mean = matrix(-2, nbBlocks[1], nbBlocks[2]))))
+  expect_error(BipartiteSBM$new('gaussian', nbNodes, blockProp, list(mean = matrix(2 , nbBlocks[1] - 1, nbBlocks[2]))))
 
   ## Checking class
   expect_true(inherits(mySampler, "SBM"))
-  expect_true(inherits(mySampler, "SBM_sampler"))
-  expect_true(inherits(mySampler, "BipartiteSBM_sampler"))
+  expect_true(inherits(mySampler, "BipartiteSBM"))
 
   ## Checking field access and format
 
   ## parameters
   expect_equal(mySampler$modelName, 'gaussian')
-  expect_equal(mySampler$nbNodes, nbNodes)
-  expect_equal(mySampler$dimension, nbNodes)
+  expect_equal(unname(mySampler$nbNodes), nbNodes)
   expect_equal(mySampler$nbDyads, nbNodes[1]*nbNodes[2])
   expect_equal(mySampler$connectParam$mean, means)
   expect_gt(mySampler$connectParam$var, 0)
+
+  ## network
+  mySampler$rMemberships(store = TRUE)
+  mySampler$rEdges(store = TRUE)
   expect_equal(dim(mySampler$expectation), nbNodes)
-  expect_false(isSymmetric(mySampler$netMatrix))
+  expect_false(isSymmetric(mySampler$networkData))
 
   ## blocks
   expect_equal(mySampler$blockProp, blockProp)
